@@ -181,6 +181,12 @@ Action.prototype = {
         a['moniker'] = this.moniker;
         a['class']   = this.actionClass;
 
+        if (this.register && this.register.id) {
+            var tmp = this.register.id.match(/^J:A-(\d+)-/);
+            if (tmp.length == 2)
+                a['order'] = tmp[1];
+        }
+
         a['fields']  = {};
         var fields = this.fields();
         for (var i = 0; i < fields.length; i++) {
@@ -437,7 +443,14 @@ ActionField.prototype = {
                             fields.push('id', tthis.element_id());
                             if (tthis.current_value) fields.push('value', tthis.current_value);
                             fields.push('class', tthis._widget_class().join(' '));
-                            if (tthis.max_length) fields.push('size', tthis.max_length, 'maxlength', tthis.max_length);
+                            if (tthis.display_length) {
+                                fields.push('size', tthis.display_length)
+                            }
+                            else if (tthis.max_length) {
+                                fields.push('size', tthis.max_length)
+                            }
+
+                            if (tthis.max_length) fields.push('maxlength', tthis.max_length);
                             if (tthis.disable_autocomplete) fields.push('autocomplete', "off");
                             //" " .$self->other_widget_properties;
                             return fields;
@@ -706,7 +719,7 @@ Behaviour.register({
             var button = document.createElement('input');
             button.setAttribute('type',  'button');
             jQuery(button).insertAfter(e);
-            jQuery(button).timepickr({});
+            jQuery(button).timepickr({val: 'Pick time'});
             jQuery(button).blur( function() { 
                 var old_value = jQuery(this).prev().val();
                 if ( Jifty.Calendar.dateRegex.test(old_value) ) {
@@ -761,18 +774,20 @@ Behaviour.register({
         }
     },
     /* Use jQuery for full-page-refresh notifications, as well */
-    '#messages.jifty.results.messages, #errors.jifty.results.messages': function(e) {
+    '#messages.jifty.results.messages, #errors.jifty.results.messages, .popup_message, .popup_error': function(e) {
         jQuery(e).hide();
     },
-    '#messages.jifty.results.messages .message': function(e) {
+    '#messages.jifty.results.messages .message, .popup_message': function(e) {
+        var sticky = jQuery(e).hasClass('popup_sticky');
         jQuery.jGrowl( e.innerHTML, {
-            sticky: true,
+            sticky: sticky,
             theme: 'result-message'
         });
     },
-    '#errors.jifty.results.messages .error': function(e) {
+    '#errors.jifty.results.messages .error, .popup_error': function(e) {
+        var sticky = jQuery(e).hasClass('popup_sticky');
         jQuery.jGrowl( e.innerHTML, {
-            sticky: true,
+            sticky: sticky,
             theme: 'result-error'
         });
     }
@@ -1291,6 +1306,25 @@ Jifty.update = function () {
         // Grab the XML response
         var response = responseXML.documentElement;
 
+        /* var response is an xml , which's content is like:
+        <response>
+            <fragment id="__page-region-name">
+                <argument name="argument1">value1</argument>
+                <argument name="argument2">value2</argument>
+                <content> 
+                        ...
+                </content>
+            </fragment>
+            <result class="MyApp::Action::DoPost" moniker="do-post">
+                <success>1</success>
+                <content>
+                    <title>Title</title>
+                    <id>123</id>
+                </content>
+            </result>
+        </response>
+        */
+
         // Look through the action results looking for field validation errors
         walk_node(response, { 
             result: function(result) {
